@@ -297,6 +297,8 @@ class MongodbHelper(BaseSqlHelper):
                 column, op = order
                 order_item.setdefault(column, 1 if op == "ASC" else -1)
             aggregate.append({"$sort": order_item})
+        if condition_wrapper.column != "*":
+            aggregate.append({"$project": condition_wrapper.column})
         return aggregate
 
     def prepare_page_sql(self, condition_wrapper: ConditionWrapper, page_num: int, page_size: int):
